==> haskell-hedgehog-classes-0.2.5.4-69-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-DgI75sJS4MMIN0OBds6Qy7
key:                  hedgehog-classes-0.2.5.4-DgI75sJS4MMIN0OBds6Qy7
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  579db1d9effc5d8d88ea782a34b89145
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-DgI75sJS4MMIN0OBds6Qy7
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0 binary-0.8.9.0
    comonad-5.0.8-ECGCXO0IDm6CmzMMLQMWdW containers-0.6.5.1
    hedgehog-1.2-6PcYeqnRpof27D7X8ClW1m
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    semirings-0.6-HrLFL9KATFkDlEaoQRKJLH
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT transformers-0.5.6.2
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh
    wl-pprint-annotated-0.1.0.1-GlZzVuuvD02T3IoeiFuSS

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-classes-0.2.5.4-78-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-Ekpiql0XQ17HT9aIk5SDiU
key:                  hedgehog-classes-0.2.5.4-Ekpiql0XQ17HT9aIk5SDiU
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  5c8b6ff3b1d42b8bc6b52a053c98ed94
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-Ekpiql0XQ17HT9aIk5SDiU
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0 binary-0.8.9.0
    comonad-5.0.8-ApzGC3RbXnnLePVoN4sF11 containers-0.6.5.1
    hedgehog-1.2-45sXUMtiCZS9ksRmbj0vBk
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    semirings-0.6-1Mmgwd2bHEZ2ZWjOvPwut1
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT transformers-0.5.6.2
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    wl-pprint-annotated-0.1.0.1-21h7Z48YMr241LjtceCswg

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
